"""
json exception
"""
mail_thunder_cant_reformat_json_error = "Can't reformat json is type right?"
mail_thunder_wrong_json_data_error = "Can't parser json"
"""
content data error
"""
mail_thunder_content_set_compiler_error = "When set compiler using content make an error"
mail_thunder_content_file_error = "MailThunder content file error"
mail_thunder_content_login_failed = "can't login with mail thunder content"
"""
argparse
"""
mail_thunder_service_file_error = "service param -s got the wrong data"
mail_thunder_login_error = "need set --user and --password to login"
mail_thunder_argparse_get_wrong_function = "get unknown function"
"""
SMTP 
"""

"""
IMAP
"""
