class MailThunderException(Exception):
    pass


class MailThunderJsonException(Exception):
    pass


class MailThunderContentException(Exception):
    pass


class MailThunderArgparseException(Exception):
    pass
